pub struct SendWindow { /* private fields */ }Implementations
Sourceimpl SendWindow
impl SendWindow
pub fn new(initial: i64) -> Self
pub fn value(&self) -> i64
Sourcepub fn adjust(&mut self, delta: i64)
pub fn adjust(&mut self, delta: i64)
Adjust by a SETTINGS_INITIAL_WINDOW_SIZE change (delta may be negative).
Sourcepub fn consume(&mut self, n: i64)
pub fn consume(&mut self, n: i64)
Consume capacity that a positive check already confirmed is available.
pub fn is_closed(&self) -> bool
Sourcepub fn register_waker(&mut self, waker: &Waker)
pub fn register_waker(&mut self, waker: &Waker)
Park a waker to be notified when capacity becomes positive (or on close).